@@ -55,7 +55,7 @@ use RT::Shredder;
 
 package RT::Extension::MergeUsers;
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 =head1 NAME
 
@@ -494,6 +494,23 @@ my $orig_has_right = \&RT::Principal::HasRight;
     return 0;
 };
 
+sub Ids {
+    my $self = shift;
+    my $id   = shift;
+    my @ids  = $id;
+
+    my $principal = RT::Principal->new( RT->SystemUser );
+    $principal->Load($id);
+
+    if ( $principal->IsUser ) {
+
+        # Not call GetMergedUsers as we don't want to create the attribute here
+        my $merged_users = $principal->Object->FirstAttribute('MergedUsers');
+        push @ids, @{ $merged_users->Content } if $merged_users;
+    }
+    return @ids;
+}
+
 {
     package RT::Group;
     my $orig_delete_member = \&RT::Group::DeleteMember;
@@ -553,16 +570,8 @@ my $orig_has_right = \&RT::Principal::HasRight;
             FIELD2 => 'GroupId',
         );
 
-        my $principal = RT::Principal->new( $self->CurrentUser );
-        $principal->Load($args{'PrincipalId'});
-        my @ids = $args{'PrincipalId'};
-        if ( $principal->IsUser ) {
-
-            # Not call GetMergedUsers as we don't want to create the attribute here
-            my $merged_users = $principal->Object->FirstAttribute('MergedUsers');
-            push @ids, @{ $merged_users->Content } if $merged_users;
-        }
 
+        my @ids = RT::Principal->Ids( $args{'PrincipalId'} );
         $self->Limit(ALIAS => $members, FIELD => 'MemberId', OPERATOR => 'IN', VALUE => \@ids);
         $self->Limit(ALIAS => $members, FIELD => 'Disabled', VALUE => 0)
             if $args{'Recursively'};
@@ -587,15 +596,8 @@ my $orig_has_right = \&RT::Principal::HasRight;
             DISTINCT => $members eq 'GroupMembers',
         );
 
-        my $principal = RT::Principal->new( $self->CurrentUser );
-        $principal->Load($args{'PrincipalId'});
-        my @ids = $args{'PrincipalId'};
-        if ( $principal->IsUser ) {
+        my @ids = RT::Principal->Ids( $args{'PrincipalId'} );
 
-            # Not call GetMergedUsers as we don't want to create the attribute here
-            my $merged_users = $principal->Object->FirstAttribute('MergedUsers');
-            push @ids, @{ $merged_users->Content } if $merged_users;
-        }
         $self->Limit(
             LEFTJOIN => $members_alias,
             ALIAS    => $members_alias,
@@ -689,6 +691,50 @@ sub TweakRoleLimitArgs {
     };
 }
 
+{
+    package RT::ACL;
+    no warnings 'redefine';
+
+    my $orig_limit = RT::ACL->can('Limit');
+    *Limit = sub {
+        my $self = shift;
+        my %args = @_;
+        if (   $args{FIELD} eq 'MemberId'
+            && ( $args{OPERATOR} || '=' ) =~ /^!?=$/
+            && $args{VALUE} =~ /^(\d+)$/ )
+        {
+            my @ids = RT::Principal->Ids($1);
+            if ( @ids > 1 ) {
+                $args{OPERATOR} = ( $args{OPERATOR} || '=' ) eq '=' ? 'IN' : 'NOT IN';
+                $args{VALUE}    = \@ids;
+            }
+        }
+        return $orig_limit->( $self, %args );
+    };
+}
+
+{
+    package RT::Tickets;
+    no warnings 'redefine';
+
+    my $orig_limit = RT::Tickets->can('Limit');
+    *Limit = sub {
+        my $self = shift;
+        my %args = @_;
+        if (   $args{FIELD} eq 'Owner'
+            && ( $args{OPERATOR} || '=' ) =~ /^!?=$/
+            && $args{VALUE} =~ /^(\d+)$/ )
+        {
+            my @ids = RT::Principal->Ids($1);
+            if ( @ids > 1 ) {
+                $args{OPERATOR} = ( $args{OPERATOR} || '=' ) eq '=' ? 'IN' : 'NOT IN';
+                $args{VALUE}    = \@ids;
+            }
+        }
+        return $orig_limit->( $self, %args );
+    };
+}
+
 =head1 AUTHOR
 
 Best Practical Solutions, LLC E<lt>modules@bestpractical.comE<gt>
